"""
    This file is part of Accountant.

    Accountant is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Accountant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with Accountant.  If not, see <http://www.gnu.org/licenses/>.
"""
import dateutil.parser

from flask.ext.restful import reqparse

from .. import api

# Parser for a date range.
range_parser = api.parser()
range_parser.add_argument(
    'begin',
    type=lambda a: dateutil.parser.parse(a) if a else None,
    required=False,
    default=None,
    location='args',
    help='Begin date of the time period'
)
range_parser.add_argument(
    'end',
    type=lambda a: dateutil.parser.parse(a) if a else None,
    required=False,
    default=None,
    location='args',
    help='End date of the time period'
)

# Parser for an account id.
account_id_parser = reqparse.RequestParser()
account_id_parser.add_argument(
    'account_id',
    type=int,
    required=True,
    location='args',
    help='Id of the account'
)

# Parser for a date range and an account id.
account_range_parser = range_parser.copy()
account_range_parser.add_argument(
    'account_id',
    type=int,
    required=True,
    location='args',
    help='Id of the account'
)
